Learn R Programming

Homeric (version 0.1-3)

Homeric-package: \Sexpr[results=rd,stage=build]{tools:::Rd_package_title("#1")}HomericDoughnut Plots

Description

\Sexpr[results=rd,stage=build]{tools:::Rd_package_description("#1")}HomericA simple implementation of doughnut plots - pie charts with a blank center. The package is named after Homer Simpson - arguably the best-known lover of doughnuts.

Arguments

Details

\Sexpr[results=rd,stage=build]{tools:::Rd_package_DESCRIPTION("#1")}HomericThis package was not yet installed at build time.

\Sexpr[results=rd,stage=build]{tools:::Rd_package_indices("#1")}Homeric Index: This package was not yet installed at build time.

Examples

Run this code
par(mar=rep(0,4), oma=rep(0, 4))
PlotDoughnut(1:5)

Run the code above in your browser using DataLab