\Sexpr[results=rd,stage=build]{tools:::Rd_package_description("#1")}HomericA simple implementation of doughnut plots - pie charts with a blank center. The package is named after Homer Simpson - arguably the best-known lover of doughnuts.
Arguments
Details
\Sexpr[results=rd,stage=build]{tools:::Rd_package_DESCRIPTION("#1")}HomericThis package was not yet installed at build time.
\Sexpr[results=rd,stage=build]{tools:::Rd_package_indices("#1")}Homeric
Index: This package was not yet installed at build time.